@@ -52,7 +52,6 @@
 #include <KWayland/Client/surface.h>
 #endif
 
-#include <config-plasma.h>
 #if HAVE_XCB_SHAPE
 #include <QX11Info>
 #include <xcb/shape.h>
@@ -191,7 +190,7 @@ QRect DialogPrivate::availableScreenGeometryForPosition(const QPoint& pos) const
      * more reliable anyways (could be tried to remove the whole Q_FOREACH
      * at this point)
      *
-     * imporant: screen can be a nullptr... see bug 345173
+     * important: screen can be a nullptr... see bug 345173
      */
     if (avail.isEmpty() && q->screen()) {
         avail = q->screen()->availableGeometry();
@@ -268,9 +267,6 @@ void DialogPrivate::updateTheme()
 
 void DialogPrivate::updateVisibility(bool visible)
 {
-    if (mainItem) {
-        mainItem->setVisible(visible);
-    }
     if (visible) {
         if (visualParent && visualParent->window()) {
             q->setTransientParent(visualParent->window());
@@ -783,7 +779,7 @@ void Dialog::setMainItem(QQuickItem *mainItem)
 
         if (d->mainItem) {
             disconnect(d->mainItem, nullptr, this, nullptr);
-            d->mainItem->setVisible(false);
+            d->mainItem->setParentItem(nullptr);
         }
 
         if (d->mainItemLayout) {
@@ -793,7 +789,6 @@ void Dialog::setMainItem(QQuickItem *mainItem)
         d->mainItem = mainItem;
 
         if (mainItem) {
-            d->mainItem->setVisible(isVisible());
             mainItem->setParentItem(contentItem());
 
             connect(mainItem, SIGNAL(widthChanged()), this, SLOT(slotMainItemSizeChanged()));
@@ -947,7 +942,7 @@ QPoint Dialog::popupPosition(QQuickItem *item, const QSize &size)
     QRect avail = item->window()->screen()->availableGeometry();
 
     if (outsideParentWindow && d->frameSvgItem->enabledBorders() != Plasma::FrameSvg::AllBorders) {
-        //make the panel look it's inside the panel, in order to not make it look cutted
+        //make the panel look it's inside the panel, in order to not make it look cut
         switch (d->location) {
         case Plasma::Types::LeftEdge:
         case Plasma::Types::RightEdge:
@@ -1360,16 +1355,9 @@ void Dialog::setVisible(bool visible)
         if (visible && d->visualParent) {
             setPosition(popupPosition(d->visualParent, size()));
         }
-        //setting the main item visible before the show event arrives
-        //makes positioning work better
-        if (visible && d->mainItem) {
-            d->mainItem->setVisible(true);
-        }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
         // Bug 381242: Qt remembers minimize state and re-applies it when showing
         setWindowStates(windowStates() & ~Qt::WindowMinimized);
-#endif
         QQuickWindow::setVisible(visible);
         //signal will be emitted and proxied from the QQuickWindow code
     } else {
